@@ -6,9 +6,10 @@ use Moose;
 use namespace::autoclean;
 use Carp;
 use Math::Vector::Real;
-use MooseX::Storage;
-with Storage( 'io' => 'StorableFile' ), 'HackaMol::NameRole',
-  'HackaMol::AtomGroupRole';
+use MooseX::StrictConstructor;
+#use MooseX::Storage;
+#with Storage( 'io' => 'StorableFile' ), 
+with 'HackaMol::NameRole', 'HackaMol::AtomGroupRole';
 
 has $_ => (
     is        => 'rw',
@@ -93,7 +94,7 @@ HackaMol::Angle - Angle class for HackaMol
 
 =head1 VERSION
 
-version 0.00_12
+version 0.00_13
 
 =head1 SYNOPSIS
 
@@ -238,11 +239,7 @@ L<HackaMol::Dihedral>
 
 =item * L<HackaMol::NameRole>
 
-=item * L<MooseX::Storage::Basic>
-
-=item * L<MooseX::Storage::Basic|MooseX::Storage::IO::StorableFile|HackaMol::NameRole|HackaMol::AtomGroupRole>
-
-=item * L<MooseX::Storage::IO::StorableFile>
+=item * L<HackaMol::NameRole|HackaMol::AtomGroupRole>
 
 =back
 
