@@ -5,9 +5,10 @@ use 5.008;
 use Moose;
 use namespace::autoclean;
 use Carp;
-use MooseX::Storage;
-with Storage( 'io' => 'StorableFile' ), 'HackaMol::NameRole',
-  'HackaMol::AtomGroupRole';
+use MooseX::StrictConstructor;
+#use MooseX::Storage;
+#with Storage( 'io' => 'StorableFile' ), 
+with 'HackaMol::NameRole', 'HackaMol::AtomGroupRole';
 
 has $_ => (
     is      => 'rw',
@@ -76,7 +77,7 @@ HackaMol::Bond - HackaMol Bond class
 
 =head1 VERSION
 
-version 0.00_12
+version 0.00_13
 
 =head1 SYNOPSIS
 
@@ -234,11 +235,7 @@ L<Chemistry::Bond>
 
 =item * L<HackaMol::NameRole>
 
-=item * L<MooseX::Storage::Basic>
-
-=item * L<MooseX::Storage::Basic|MooseX::Storage::IO::StorableFile|HackaMol::NameRole|HackaMol::AtomGroupRole>
-
-=item * L<MooseX::Storage::IO::StorableFile>
+=item * L<HackaMol::NameRole|HackaMol::AtomGroupRole>
 
 =back
 
