@@ -5,10 +5,11 @@ use 5.008;
 use Moose;
 use namespace::autoclean;
 use Carp;
-use MooseX::Storage;
 use Math::Trig;
-with Storage( 'io' => 'StorableFile' ), 'HackaMol::NameRole',
-  'HackaMol::AtomGroupRole';
+use MooseX::StrictConstructor;
+#use MooseX::Storage;
+#with Storage( 'io' => 'StorableFile' ), 
+with 'HackaMol::NameRole', 'HackaMol::AtomGroupRole';
 
 has $_ => (
     is      => 'rw',
@@ -93,7 +94,7 @@ HackaMol::Dihedral - Dihedral Angle class for HackaMol
 
 =head1 VERSION
 
-version 0.00_12
+version 0.00_13
 
 =head1 SYNOPSIS
 
@@ -244,11 +245,7 @@ L<HackaMol::Angle>
 
 =item * L<HackaMol::NameRole>
 
-=item * L<MooseX::Storage::Basic>
-
-=item * L<MooseX::Storage::Basic|MooseX::Storage::IO::StorableFile|HackaMol::NameRole|HackaMol::AtomGroupRole>
-
-=item * L<MooseX::Storage::IO::StorableFile>
+=item * L<HackaMol::NameRole|HackaMol::AtomGroupRole>
 
 =back
 
